/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsEnvironmentRefAccessor.java 3979 2008-09-28 11:02:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.interfaces.IEnvironmentRefAccessor;
import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IEnvEntry;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;

/**
 * This class provides method to keep env state.
 * @author Gael Lalire
 */
public class AbsEnvironmentRefAccessor implements IEnvironmentRefAccessor {

    /**
     * metadata shared with class, field and method.
     */
    private ISharedMetadata sharedMetadata;

    /**
     * Object representing &#64;{@link javax.ejb.EJBs} annotation.
     */
    private List<IJEjbEJB> jEjbEJBs = null;

    /**
     * Object representing &#64;{@link javax.annotation.Resources} annotation.
     */
    private List<IJAnnotationResource> jAnnotationResources = null;

    /**
     * Object representing &#64;{@link javax.persistence.PersistenceContext} annotation.
     */
    private List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts = null;

    /**
     * Object representing &#64;{@link javax.persistence.PersistenceUnit} annotation.
     */
    private List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits = null;

    /**
     * Object representing &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    private List<IJaxwsWebServiceRef> javaxXmlWsWebSreviceRefs = null;

    /**
     * envEntryCollection.
     */
    private Collection<? extends IEnvEntry> envEntryCollection;

    /**
     * Constructor.
     */
    public AbsEnvironmentRefAccessor() {
        sharedMetadata = new AbsSharedMetadata();
        envEntryCollection = new ArrayList<IEnvEntry>();
    }

    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    public final IJEjbEJB getJEjbEJB() {
        return this.sharedMetadata.getJEjbEJB();
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    public final void setJEjbEJB(final IJEjbEJB jEjbEJB) {
        this.sharedMetadata.setJEjbEJB(jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    public final IJAnnotationResource getJAnnotationResource() {
        return this.sharedMetadata.getJAnnotationResource();
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    public final void setJAnnotationResource(final IJAnnotationResource jAnnotationResource) {
        this.sharedMetadata.setJAnnotationResource(jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    public final boolean isPersistenceContext() {
        return this.sharedMetadata.isPersistenceContext();
    }

    /**
     * @return the persistence context infos.
     */
    public final IJavaxPersistenceContext getJavaxPersistenceContext() {
        return this.sharedMetadata.getJavaxPersistenceContext();
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    public final void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        this.sharedMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    public final boolean isPersistenceUnit() {
        return this.sharedMetadata.isPersistenceUnit();
    }

    /**
     * @return the persistence unit infos.
     */
    public final IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return this.sharedMetadata.getJavaxPersistenceUnit();
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    public final void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        this.sharedMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs} annotation.
     */
    public final List<IJEjbEJB> getJEjbEJBs() {
        return this.jEjbEJBs;
    }

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    public final void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs) {
        this.jEjbEJBs = jEjbEJBs;
    }

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    public final List<IJAnnotationResource> getJAnnotationResources() {
        return this.jAnnotationResources;
    }

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    public final void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources) {
        this.jAnnotationResources = jAnnotationResources;
    }

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    public final List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts() {
        return this.javaxPersistencePersistenceContexts;
    }

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    public final void setJavaxPersistencePersistenceContexts(
            final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts) {
        this.javaxPersistencePersistenceContexts = javaxPersistencePersistenceContexts;
    }

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits() {
        return this.javaxPersistencePersistenceUnits;
    }

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits) {
        this.javaxPersistencePersistenceUnits = javaxPersistencePersistenceUnits;
    }

    /**
     * @return jaxwsWebServiceRefs list representing &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs() {
        return this.javaxXmlWsWebSreviceRefs;
    }

    /**
     * Sets setJaxwsWebServiceRefs object.
     *
     * @param jaxwsWebServiceRefs list representing &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public void setJaxwsWebServiceRefs(final List<IJaxwsWebServiceRef> jaxwsWebServiceRefs) {
        this.javaxXmlWsWebSreviceRefs = jaxwsWebServiceRefs;
    }

    /**
     * {@inheritDoc}
     */
    public Collection<? extends IEnvEntry> getEnvEntryCollection() {
        return envEntryCollection;
    }

    /**
     * {@inheritDoc}
     */
    public void setEnvEntryCollection(final Collection<? extends IEnvEntry> envEntryCollection) {
        this.envEntryCollection = envEntryCollection;
    }

    /**
     * @return the WebServiceRef infos
     */
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return sharedMetadata.getJaxwsWebServiceRef();
    }

    /**
     * Sets the WebServiceRef infos
     * @param jaxwsWebServiceRef information on WebServiceRef
     */
    public void setJaxwsWebServiceRef(final IJaxwsWebServiceRef jaxwsWebServiceRef) {
        this.sharedMetadata.setJaxwsWebServiceRef(jaxwsWebServiceRef);
    }

    /**
     * @return the HandlerChain infos
     */
    public IJwsHandlerChain getJwsHandlerChain() {
        return sharedMetadata.getJwsHandlerChain();
    }

    /**
     * Sets the HandlerChain infos
     * @param jwsHandlerChain information on HandlerChain
     */
    public void setJwsHandlerChain(final IJwsHandlerChain jwsHandlerChain) {
        this.sharedMetadata.setJwsHandlerChain(jwsHandlerChain);
    }

    public String getEnvironmentName() {
        return "no name";
    }

}
