/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonClassMetadata.java 3804 2008-08-07 13:57:58Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.scan.api.metadata.ClassMetadata;
import org.ow2.util.scan.api.metadata.structures.JClass;

import java.util.List;

/**
 * EZB common class metadata.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public class CommonClassMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ClassMetadata<C, M, F> implements ICommonClassMetadata<C, M, F> {

    /**
     * Environnement accessor.
     */
    private AbsEnvironmentRefAccessor environmentRefAccessor;

    /**
     * Constructor.
     * @param jClass signature
     */
    protected CommonClassMetadata(final JClass jClass) {
        super(jClass);
        this.environmentRefAccessor = new AbsEnvironmentRefAccessor();
    }

    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    public final IJEjbEJB getJEjbEJB() {
        return this.environmentRefAccessor.getJEjbEJB();
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    public final void setJEjbEJB(final IJEjbEJB jEjbEJB) {
        this.environmentRefAccessor.setJEjbEJB(jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    public final IJAnnotationResource getJAnnotationResource() {
        return this.environmentRefAccessor.getJAnnotationResource();
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    public final void setJAnnotationResource(final IJAnnotationResource jAnnotationResource) {
        this.environmentRefAccessor.setJAnnotationResource(jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    public final boolean isPersistenceContext() {
        return this.environmentRefAccessor.isPersistenceContext();
    }

    /**
     * @return the persistence context infos.
     */
    public final IJavaxPersistenceContext getJavaxPersistenceContext() {
        return this.environmentRefAccessor.getJavaxPersistenceContext();
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    public final void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        this.environmentRefAccessor.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    public final boolean isPersistenceUnit() {
        return this.environmentRefAccessor.isPersistenceUnit();
    }

    /**
     * @return the persistence unit infos.
     */
    public final IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return this.environmentRefAccessor.getJavaxPersistenceUnit();
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    public final void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        this.environmentRefAccessor.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs} annotation.
     */
    public final List<IJEjbEJB> getJEjbEJBs() {
        return this.environmentRefAccessor.getJEjbEJBs();
    }

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    public final void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs) {
        this.environmentRefAccessor.setJEjbEJBs(jEjbEJBs);
    }

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    public final List<IJAnnotationResource> getJAnnotationResources() {
        return this.environmentRefAccessor.getJAnnotationResources();
    }

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    public final void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources) {
        this.environmentRefAccessor.setJAnnotationResources(jAnnotationResources);
    }

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    public final List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts() {
        return this.environmentRefAccessor.getJavaxPersistencePersistenceContexts();
    }

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    public final void setJavaxPersistencePersistenceContexts(
            final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts) {
        this.environmentRefAccessor.setJavaxPersistencePersistenceContexts(javaxPersistencePersistenceContexts);
    }

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits() {
        return this.environmentRefAccessor.getJavaxPersistencePersistenceUnits();
    }

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits) {
        this.environmentRefAccessor.setJavaxPersistencePersistenceUnits(javaxPersistencePersistenceUnits);
    }

    /**
     * @return jaxwsWebServiceRefs list representing
     *         &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs() {
        return environmentRefAccessor.getJaxwsWebServiceRefs();
    }

    /**
     * Sets jaxwsWebServiceRefs object.
     *
     * @param jaxwsWebServiceRefs list representing
     *                            &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public void setJaxwsWebServiceRefs(List<IJaxwsWebServiceRef> jaxwsWebServiceRefs) {
        environmentRefAccessor.setJaxwsWebServiceRefs(jaxwsWebServiceRefs);
    }

    /**
     * @return IJWebServiceRef object representing javax.xml.ws.WebServiceRef annotation.
     */
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return environmentRefAccessor.getJaxwsWebServiceRef();
    }

    /**
     * Set JWebServiceRef object.
     *
     * @param wsr object representing javax.xml.ws.WebServiceRef annotation.
     */
    public void setJaxwsWebServiceRef(IJaxwsWebServiceRef wsr) {
        environmentRefAccessor.setJaxwsWebServiceRef(wsr);
    }

    /**
     * @return IJwsHandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public IJwsHandlerChain getJwsHandlerChain() {
        return environmentRefAccessor.getJwsHandlerChain();
    }

    /**
     * Set JwsHandlerChain object.
     *
     * @param jwshandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public void setJwsHandlerChain(IJwsHandlerChain jwshandlerChain) {
        environmentRefAccessor.setJwsHandlerChain(jwshandlerChain);
    }
}
