package org.ow2.util.ee.metadata.common.impl.configurator;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationResourcesVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxEjbEJBsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceContextsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceUnitsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxXmlWsWebServiceRefsVisitor;
import org.ow2.util.scan.api.configurator.metadata.ClassMetadataConfigurator;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificArchiveConfigurator;

import java.util.List;

/**
 * CommonClassMetadataConfigurator.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonClassMetadataConfigurator<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ClassMetadataConfigurator<C, M, F> {

    /**
     * Constructor.
     * @param classMetadata classMetadata
     * @param specificArchiveConfiguratorList specific archive configurator list
     */
    public CommonClassMetadataConfigurator(final C classMetadata,
            final List<? extends ISpecificArchiveConfigurator<C, M, F>> specificArchiveConfiguratorList) {
        super(classMetadata, specificArchiveConfiguratorList);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {

        C classMetadata = getClassMetadata();

        // add visitor shared with class and field and method
        CommonMetadataConfigurator.initVisitor(getAnnotationVisitors(), classMetadata);

        // add @EJBs
        getAnnotationVisitors().put(JavaxEjbEJBsVisitor.TYPE,
                new JavaxEjbEJBsVisitor(classMetadata));

        // add @Resources
        getAnnotationVisitors().put(JavaxAnnotationResourcesVisitor.TYPE,
                new JavaxAnnotationResourcesVisitor(classMetadata));

        // add @PersistenceContexts
        getAnnotationVisitors().put(JavaxPersistencePersistenceContextsVisitor.TYPE,
                new JavaxPersistencePersistenceContextsVisitor(classMetadata));

        // add @PersistenceUnits
        getAnnotationVisitors().put(JavaxPersistencePersistenceUnitsVisitor.TYPE,
                new JavaxPersistencePersistenceUnitsVisitor(classMetadata));

        // add @WebServiceRefs
        getAnnotationVisitors().put(JavaxXmlWsWebServiceRefsVisitor.TYPE,
                                    new JavaxXmlWsWebServiceRefsVisitor(classMetadata));

    }

}
