/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxXmlWsWebServiceRefsVisitor.java 3804 2008-08-07 13:57:58Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxXmlWsWebServiceRefVisitor;
import org.ow2.util.ee.metadata.common.impl.struct.JaxwsWebServiceRef;

import java.util.ArrayList;
import java.util.List;

/**
 * This class manages the handling of &#64;{@link javax.xml.ws.WebServiceRefs}
 * annotation.
 * @author Guillaume Sauthier
 */
public class JavaxXmlWsWebServiceRefsVisitor extends
        JavaxXmlWsWebServiceRefVisitor<ICommonClassMetadata<?, ?, ?>> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/xml/ws/WebServiceRefs;";

    /**
     * List of JaxwsWebServiceRefs object.
     */
    private List<IJaxwsWebServiceRef> jaxwsWebServiceRefs = null;

    /**
     * Object is added to the list.
     */
    private boolean isAdded = false;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class metadata
     */
    public JavaxXmlWsWebServiceRefsVisitor(final ICommonClassMetadata<?, ?, ?> annotationMetadata) {
        super(annotationMetadata);
        jaxwsWebServiceRefs = new ArrayList<IJaxwsWebServiceRef>();
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(final String name, final Object value) {
        // list not empty, need to create another reference
        // at the first item found
        if (jaxwsWebServiceRefs.size() > 0 && isAdded) {
            setJaxwsWebServiceRef(new JaxwsWebServiceRef());
            isAdded = false;
        }

        // do super code
        super.visit(name, value);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // add object in the list
        if (!isAdded) {
            jaxwsWebServiceRefs.add(getJaxwsWebServiceRef());
            isAdded = true;
        }

        // update list
        getAnnotationMetadata().setJaxwsWebServiceRefs(jaxwsWebServiceRefs);
    }

    /**
     * @return type of the annotation (its description)
     */
    @Override
    public String getType() {
        return TYPE;
    }

}
