/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: SpecificCommonClassMetadata.java 3979 2008-09-28 11:02:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.specific;

import java.util.Collection;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;
import org.ow2.util.scan.api.metadata.specific.SpecificClassMetadata;
import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * You can extends this class to create a specific common class metadata.
 * @param <C> standard class metadata
 * @param <M> standard method metadata
 * @param <F> standard field metadata
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificCommonClassMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>,
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificClassMetadata<SC, SM, SF> implements ICommonClassMetadata<C, M, F> {

    /**
     * The standard common class metadata.
     */
    private ICommonClassMetadata<C, M, F> commonClassMetadata;

    /**
     * Construct delegation.
     * @param commonClassMetadata the standard common class metadata.
     */
    protected SpecificCommonClassMetadata(final ICommonClassMetadata<C, M, F> commonClassMetadata) {
        this.commonClassMetadata = commonClassMetadata;
    }

    /**
     * {@inheritDoc}
     */
    public JClass getJClass() {
        return commonClassMetadata.getJClass();
    }

    /**
     * {@inheritDoc}
     */
    public void setJClass(final JClass class1) {
        commonClassMetadata.setJClass(class1);
    }

    /**
     * {@inheritDoc}
     */
    public List<IJAnnotationResource> getJAnnotationResources() {
        return commonClassMetadata.getJAnnotationResources();
    }

    /**
     * {@inheritDoc}
     */
    public List<IJEjbEJB> getJEjbEJBs() {
        return commonClassMetadata.getJEjbEJBs();
    }

    /**
     * {@inheritDoc}
     */
    public List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts() {
        return commonClassMetadata.getJavaxPersistencePersistenceContexts();
    }

    /**
     * {@inheritDoc}
     */
    public List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits() {
        return commonClassMetadata.getJavaxPersistencePersistenceUnits();
    }

    /**
     * {@inheritDoc}
     */
    public void setJAnnotationResources(final List<IJAnnotationResource> annotationResources) {
        commonClassMetadata.setJAnnotationResources(annotationResources);
    }

    /**
     * {@inheritDoc}
     */
    public void setJEjbEJBs(final List<IJEjbEJB> ejbEJBs) {
        commonClassMetadata.setJEjbEJBs(ejbEJBs);
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistencePersistenceContexts(final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts) {
        commonClassMetadata.setJavaxPersistencePersistenceContexts(javaxPersistencePersistenceContexts);
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits) {
        commonClassMetadata.setJavaxPersistencePersistenceUnits(javaxPersistencePersistenceUnits);
    }

    /**
     * @return jaxwsWebServiceRefs list representing
     *         &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs() {
        return commonClassMetadata.getJaxwsWebServiceRefs();
    }

    /**
     * Sets jaxwsWebServiceRefs object.
     *
     * @param jaxwsWebServiceRefs list representing
     *                            &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public void setJaxwsWebServiceRefs(final List<IJaxwsWebServiceRef> jaxwsWebServiceRefs) {
        commonClassMetadata.setJaxwsWebServiceRefs(jaxwsWebServiceRefs);
    }

    /**
     * {@inheritDoc}
     */
    public IJEjbEJB getJEjbEJB() {
        return commonClassMetadata.getJEjbEJB();
    }

    /**
     * {@inheritDoc}
     */
    public void setJEjbEJB(final IJEjbEJB ejbEJB) {
        commonClassMetadata.setJEjbEJB(ejbEJB);
    }

    /**
     * {@inheritDoc}
     */
    public IJAnnotationResource getJAnnotationResource() {
        return commonClassMetadata.getJAnnotationResource();
    }

    /**
     * {@inheritDoc}
     */
    public void setJAnnotationResource(final IJAnnotationResource annotationResource) {
        commonClassMetadata.setJAnnotationResource(annotationResource);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceContext getJavaxPersistenceContext() {
        return commonClassMetadata.getJavaxPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceContext() {
        return commonClassMetadata.isPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        commonClassMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return commonClassMetadata.getJavaxPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceUnit() {
        return commonClassMetadata.isPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        commonClassMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * {@inheritDoc}
     */
    public void addStandardFieldMetadata(final F fieldAnnotationMetadata) {
        commonClassMetadata.addStandardFieldMetadata(fieldAnnotationMetadata);
    }

    /**
     * {@inheritDoc}
     */
    public void addStandardMethodMetadata(final M methodAnnotationMetadata) {
        commonClassMetadata.addStandardMethodMetadata(methodAnnotationMetadata);
    }

    /**
     * {@inheritDoc}
     */
    public F getStandardFieldMetadata(final JField field) {
        return commonClassMetadata.getStandardFieldMetadata(field);
    }

    /**
     * {@inheritDoc}
     */
    public Collection<? extends F> getStandardFieldMetadataCollection() {
        return commonClassMetadata.getStandardFieldMetadataCollection();
    }

    /**
     * {@inheritDoc}
     */
    public M getStandardMethodMetadata(final JMethod method) {
        return commonClassMetadata.getStandardMethodMetadata(method);
    }

    /**
     * {@inheritDoc}
     */
    public Collection<? extends M> getStandardMethodMetadataCollection() {
        return commonClassMetadata.getStandardMethodMetadataCollection();
    }

    /**
     * {@inheritDoc}
     */
    public List<? extends F> searchStandardFieldMetadata(final String fieldName) {
        return commonClassMetadata.searchStandardFieldMetadata(fieldName);
    }

    /**
     * {@inheritDoc}
     */
    public List<? extends M> searchStandardMethodMetadata(final String methodName) {
        return commonClassMetadata.searchStandardMethodMetadata(methodName);
    }

    /**
     * @return IJWebServiceRef object representing javax.xml.ws.WebServiceRef annotation.
     */
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return commonClassMetadata.getJaxwsWebServiceRef();
    }

    /**
     * Set JWebServiceRef object.
     *
     * @param wsr object representing javax.xml.ws.WebServiceRef annotation.
     */
    public void setJaxwsWebServiceRef(final IJaxwsWebServiceRef wsr) {
        commonClassMetadata.setJaxwsWebServiceRef(wsr);
    }

    /**
     * @return IJwsHandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public IJwsHandlerChain getJwsHandlerChain() {
        return commonClassMetadata.getJwsHandlerChain();
    }

    /**
     * Set JwsHandlerChain object.
     *
     * @param jwshandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public void setJwsHandlerChain(final IJwsHandlerChain jwshandlerChain) {
        commonClassMetadata.setJwsHandlerChain(jwshandlerChain);
    }
}
