/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: SpecificCommonFieldMetadata.java 3979 2008-09-28 11:02:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.specific;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;
import org.ow2.util.scan.api.metadata.specific.SpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.structures.JField;

/**
 * SpecificCommonFieldMetadata.
 * @param <C> standard class metadata
 * @param <M> standard method metadata
 * @param <F> standard field metadata
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificCommonFieldMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>,
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificFieldMetadata<SC, SM, SF> implements ICommonFieldMetadata<C, M, F> {

    /**
     * The standard common method metadata.
     */
    private ICommonFieldMetadata<C, M, F> commonFieldMetadata;

    /**
     * Construct delegation.
     * @param commonFieldMetadata the standard common field metadata.
     * @param classMetadata the specific parent
     */
    public SpecificCommonFieldMetadata(final ICommonFieldMetadata<C, M, F> commonFieldMetadata, final SC classMetadata) {
        super(classMetadata);
        this.commonFieldMetadata = commonFieldMetadata;
    }

    /**
     * {@inheritDoc}
     */
    public JField getJField() {
        return commonFieldMetadata.getJField();
    }

    /**
     * {@inheritDoc}
     */
    public IJEjbEJB getJEjbEJB() {
        return commonFieldMetadata.getJEjbEJB();
    }

    /**
     * {@inheritDoc}
     */
    public void setJEjbEJB(final IJEjbEJB ejbEJB) {
        commonFieldMetadata.setJEjbEJB(ejbEJB);
    }

    /**
     * {@inheritDoc}
     */
    public IJAnnotationResource getJAnnotationResource() {
        return commonFieldMetadata.getJAnnotationResource();
    }

    /**
     * {@inheritDoc}
     */
    public void setJAnnotationResource(final IJAnnotationResource annotationResource) {
        commonFieldMetadata.setJAnnotationResource(annotationResource);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceContext getJavaxPersistenceContext() {
        return commonFieldMetadata.getJavaxPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceContext() {
        return commonFieldMetadata.isPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        commonFieldMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return commonFieldMetadata.getJavaxPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceUnit() {
        return commonFieldMetadata.isPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        commonFieldMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * {@inheritDoc}
     */
    public C getClassMetadata() {
        return commonFieldMetadata.getClassMetadata();
    }

    /**
     * @return IJWebServiceRef object representing javax.xml.ws.WebServiceRef annotation.
     */
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return commonFieldMetadata.getJaxwsWebServiceRef();
    }

    /**
     * Set JWebServiceRef object.
     *
     * @param wsr object representing javax.xml.ws.WebServiceRef annotation.
     */
    public void setJaxwsWebServiceRef(final IJaxwsWebServiceRef wsr) {
        commonFieldMetadata.setJaxwsWebServiceRef(wsr);
    }

    /**
     * @return IJwsHandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public IJwsHandlerChain getJwsHandlerChain() {
        return commonFieldMetadata.getJwsHandlerChain();
    }

    /**
     * Set JwsHandlerChain object.
     *
     * @param jwshandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public void setJwsHandlerChain(final IJwsHandlerChain jwshandlerChain) {
        commonFieldMetadata.setJwsHandlerChain(jwshandlerChain);
    }
}
