/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: SpecificCommonMethodMetadata.java 3979 2008-09-28 11:02:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.specific;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;
import org.ow2.util.scan.api.metadata.specific.SpecificMethodMetadata;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * SpecificCommonMethodMetadata.
 * @param <C> standard class metadata
 * @param <M> standard method metadata
 * @param <F> standard field metadata
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificCommonMethodMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>,
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificMethodMetadata<SC, SM, SF> implements ICommonMethodMetadata<C, M, F> {

    /**
     * The standard common method metadata.
     */
    private ICommonMethodMetadata<C, M, F> commonMethodMetadata;

    /**
     * Construct delegation.
     * @param commonMethodMetadata the standard common method metadata.
     * @param classMetadata parent metadata
     */
    protected SpecificCommonMethodMetadata(final ICommonMethodMetadata<C, M, F> commonMethodMetadata, final SC classMetadata) {
        super(classMetadata);
        this.commonMethodMetadata = commonMethodMetadata;
    }

    /**
     * {@inheritDoc}
     */
    public JMethod getJMethod() {
        return commonMethodMetadata.getJMethod();
    }

    /**
     * {@inheritDoc}
     */
    public IJEjbEJB getJEjbEJB() {
        return commonMethodMetadata.getJEjbEJB();
    }

    /**
     * {@inheritDoc}
     */
    public void setJEjbEJB(final IJEjbEJB ejbEJB) {
        commonMethodMetadata.setJEjbEJB(ejbEJB);
    }

    /**
     * {@inheritDoc}
     */
    public IJAnnotationResource getJAnnotationResource() {
        return commonMethodMetadata.getJAnnotationResource();
    }

    /**
     * {@inheritDoc}
     */
    public void setJAnnotationResource(final IJAnnotationResource annotationResource) {
        commonMethodMetadata.setJAnnotationResource(annotationResource);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceContext getJavaxPersistenceContext() {
        return commonMethodMetadata.getJavaxPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceContext() {
        return commonMethodMetadata.isPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        commonMethodMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return commonMethodMetadata.getJavaxPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceUnit() {
        return commonMethodMetadata.isPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        commonMethodMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * {@inheritDoc}
     */
    public C getClassMetadata() {
        return commonMethodMetadata.getClassMetadata();
    }

    /**
     * {@inheritDoc}
     */
    public void setClassMetadata(final C classMetadata) {
        commonMethodMetadata.setClassMetadata(classMetadata);
    }

    /**
     * {@inheritDoc}
     */
    public void setJMethod(final JMethod method) {
        commonMethodMetadata.setJMethod(method);
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPostConstruct() {
        return commonMethodMetadata.isPostConstruct();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPreDestroy() {
        return commonMethodMetadata.isPreDestroy();
    }

    /**
     * {@inheritDoc}
     */
    public void setPostConstruct(final boolean postConstruct) {
        commonMethodMetadata.setPostConstruct(postConstruct);
    }

    /**
     * {@inheritDoc}
     */
    public void setPreDestroy(final boolean preDestroy) {
        commonMethodMetadata.setPreDestroy(preDestroy);
    }

    /**
     * @return IJWebServiceRef object representing javax.xml.ws.WebServiceRef annotation.
     */
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return commonMethodMetadata.getJaxwsWebServiceRef();
    }

    /**
     * Set JWebServiceRef object.
     *
     * @param wsr object representing javax.xml.ws.WebServiceRef annotation.
     */
    public void setJaxwsWebServiceRef(final IJaxwsWebServiceRef wsr) {
        commonMethodMetadata.setJaxwsWebServiceRef(wsr);
    }

    /**
     * @return IJwsHandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public IJwsHandlerChain getJwsHandlerChain() {
        return commonMethodMetadata.getJwsHandlerChain();
    }

    /**
     * Set JwsHandlerChain object.
     *
     * @param jwshandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public void setJwsHandlerChain(final IJwsHandlerChain jwshandlerChain) {
        commonMethodMetadata.setJwsHandlerChain(jwshandlerChain);
    }
}
