/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JwsHandlerChain.java 3804 2008-08-07 13:57:58Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.struct;

import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;

/**
 * This class allow to set informations on javax.jws.HandlerChain
 * annotation.
 * @author Guillaume Sauthier
 */
public class JwsHandlerChain implements IJwsHandlerChain {
    /**
     * Absolute URL or relative path to the handler chain file.
     */
    private String file;

    /**
     * XML serialized form of a &lt;handler-chains&gt; element.
     */
    private String serialized = null;

    /**
     * @return the absolute URL or relative path to the handler chain file.
     */
    public String getFile() {
        return file;
    }

    /**
     * Set the location of the handler chain file.
     *
     * @param file location of the handler chain file.
     */
    public void setFile(String file) {
        this.file = file;
    }

    /**
     * Return the XML serialized form of a &lt;handler-chains&gt; element.
     * This method may return null.
     *
     * @return the XML serialized form of a &lt;handler-chains&gt; element.
     */
    public String getXMLSerializedForm() {
        return serialized;
    }

    /**
     * Stores the XML serialized form of a &lt;handler-chains&gt; element.
     */
    public void setXMLSerializedForm(String serializedForm) {
        this.serialized = serializedForm;
    }

}
